<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://insiteful.co
 * @since      1.0.0
 *
 * @package    Insiteful
 * @subpackage Insiteful/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Insiteful
 * @subpackage Insiteful/public
 * @author     Insiteful <hi@insiteful.co>
 */
class Insiteful_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Insiteful_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Insiteful_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/insiteful-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Insiteful_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Insiteful_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( $this->plugin_name, '//a.insiteful.co/dist/compile.min.js', array(), $this->version, false );

		$this->insiteful_options = get_option($this->plugin_name);
		$script  = "insiteful_activate('".$this->insiteful_options['code']."');"; // replace $var with hash value
		wp_add_inline_script($this->plugin_name,  $script, 'after');
		// add_filter( 'script_loader_tag', function ( $tag, $handle ) {
		//     if ( strpos($handle, 'defer') == false )
		//         return $tag;

		//     return str_replace( '<script', '<script defer="defer"', $tag );
		// }, 10, 2 );
	}

}
